package com.persagy.dmp.rwd.edit.service;

import com.persagy.common.criteria.CriteriaExpressionParser;
import com.persagy.common.criteria.CriteriaUtils;
import com.persagy.common.criteria.JacksonCriteria;
import com.persagy.common.web.BaseResponse;
import com.persagy.common.web.MapResponse;
import com.persagy.common.web.PagedResponse;
import com.persagy.dmp.rwd.edit.entity.AdminPermission;
import com.persagy.dmp.rwd.edit.entity.AdminRole;
import com.persagy.dmp.rwd.edit.entity.QAdminPermission;
import com.persagy.dmp.rwd.edit.entity.QAdminRole;
import com.persagy.dmp.rwd.edit.repository.AdminPermissionRepository;
import com.persagy.dmp.rwd.edit.repository.AdminRoleRepository;
import com.querydsl.core.BooleanBuilder;
import com.querydsl.core.types.dsl.BooleanExpression;
import org.junit.Assert;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.junit.runner.RunWith;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.junit.MockitoJUnitRunner;
import org.mockito.junit.jupiter.MockitoExtension;

import java.util.*;

import static org.mockito.ArgumentMatchers.any;
import static org.mockito.ArgumentMatchers.eq;
import static org.mockito.Mockito.when;

@ExtendWith(MockitoExtension.class)
//@RunWith(MockitoJUnitRunner.Silent.class)
class AdminRoleServiceTest {

    @Mock
    private AdminRoleRepository mockAdminRoleRepository;
    @Mock
    private AdminPermissionRepository mockPermissionRepository;
    @Mock
    private CriteriaUtils mockCriteriaUtils;

    @InjectMocks
    private AdminRoleService adminRoleServiceUnderTest;

    @Test
    void testQuery() {
        // Setup
        final JacksonCriteria criteria = JacksonCriteria.newInstance();
        when(mockCriteriaUtils.query(eq(new QAdminRole("adminRole")), any(CriteriaExpressionParser.class), any(JacksonCriteria.class)))
                .thenReturn(new PagedResponse<>());

        // Run the test
        final PagedResponse<AdminRole> result = adminRoleServiceUnderTest.query(criteria);

        // Verify the results
        for (AdminRole datum : result.getData()) {
            Assert.assertNotNull("角色名称为空",datum.getName());
        }
    }

    @Test
    void testCreate() {
        // Setup
        final AdminRole param = new AdminRole();
        param.setId(0);
        param.setName("name");
        param.setRemark("remark");
        param.setStatus(0);
        param.setCreateUser(0);
        param.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        param.setUpdateUser(0);
        param.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        final AdminPermission adminPermission = new AdminPermission();
        adminPermission.setId(0);
        adminPermission.setSign("sign");
        adminPermission.setName("name");
        adminPermission.setRemark("remark");
        adminPermission.setStatus(0);
        adminPermission.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminPermission.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        param.setPermissions(Collections.singletonList(adminPermission));
        BooleanExpression booleanExpression = new QAdminRole("adminRole").name.eq("name");
        when(mockAdminRoleRepository.count(booleanExpression)).thenReturn(0L);

        // Configure AdminRoleRepository.save(...).
        final AdminRole adminRole = new AdminRole();
        adminRole.setId(0);
        adminRole.setName("name");
        adminRole.setRemark("remark");
        adminRole.setStatus(0);
        adminRole.setCreateUser(0);
        adminRole.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminRole.setUpdateUser(0);
        adminRole.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        final AdminPermission adminPermission1 = new AdminPermission();
        adminPermission1.setId(0);
        adminPermission1.setSign("sign");
        adminPermission1.setName("name");
        adminPermission1.setRemark("remark");
        adminPermission1.setStatus(0);
        adminPermission1.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminPermission1.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminRole.setPermissions(Collections.singletonList(adminPermission1));
        // when(mockAdminRoleRepository.save(any(AdminRole.class))).thenReturn(adminRole);
        when(mockAdminRoleRepository.save(any(AdminRole.class))).thenReturn(adminRole);
        // Run the test
        final MapResponse result = adminRoleServiceUnderTest.create(param);

        // Verify the results
        //Assert.assertEquals("测试名称为空失败","name is required",result.getMessage());
        Assert.assertEquals("处理结果成功", BaseResponse.SUCCESS,result.getResult());
    }
    @Test
    void testCreate_nameisNull() {
        // Setup
        final AdminRole param = new AdminRole();
        param.setId(0);
        //param.setName("name");
        param.setRemark("remark");
        param.setStatus(0);
        param.setCreateUser(0);
        param.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        param.setUpdateUser(0);
        param.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        final AdminPermission adminPermission = new AdminPermission();
        adminPermission.setId(0);
        adminPermission.setSign("sign");
        adminPermission.setName("name");
        adminPermission.setRemark("remark");
        adminPermission.setStatus(0);
        adminPermission.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminPermission.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        param.setPermissions(Collections.singletonList(adminPermission));
        //BooleanExpression booleanExpression = new QAdminRole("adminRole").name.eq("abc");
        //when(mockAdminRoleRepository.count(booleanExpression)).thenReturn(0L);
        // Run the test
        final MapResponse result = adminRoleServiceUnderTest.create(param);
        // Verify the results
        Assert.assertEquals("测试名称为空失败","name is required",result.getMessage());
        //Assert.assertNotNull("主键为空",result.getString("id"));
    }
    @Test
    void testCreate_nameExist() {
        // Setup
        final AdminRole param = new AdminRole();
        param.setId(0);
        param.setName("name");
        param.setRemark("remark");
        param.setStatus(0);
        param.setCreateUser(0);
        param.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        param.setUpdateUser(0);
        param.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        final AdminPermission adminPermission = new AdminPermission();
        adminPermission.setId(0);
        adminPermission.setSign("sign");
        adminPermission.setName("name");
        adminPermission.setRemark("remark");
        adminPermission.setStatus(0);
        adminPermission.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminPermission.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        param.setPermissions(Collections.singletonList(adminPermission));
        BooleanExpression booleanExpression = new QAdminRole("adminRole").name.eq("name");
        when(mockAdminRoleRepository.count(booleanExpression)).thenReturn(1L);
        // Run the test
        final MapResponse result = adminRoleServiceUnderTest.create(param);

        // Verify the results
        Assert.assertEquals("测试名称为空失败","name is exists",result.getMessage());
    }

    @Test
    void testUpdate() {
        // Setup
        final AdminRole param = new AdminRole();
        param.setId(0);
        param.setName("name");
        param.setRemark("remark");
        param.setStatus(0);
        param.setCreateUser(0);
        param.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        param.setUpdateUser(0);
        param.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        final AdminPermission adminPermission = new AdminPermission();
        adminPermission.setId(0);
        adminPermission.setSign("sign");
        adminPermission.setName("name");
        adminPermission.setRemark("remark");
        adminPermission.setStatus(0);
        adminPermission.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminPermission.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        param.setPermissions(new ArrayList<>(Collections.singletonList(adminPermission)));

        // Configure AdminRoleRepository.findById(...).
        final AdminRole adminRole1 = new AdminRole();
        adminRole1.setId(0);
        adminRole1.setName("name");
        adminRole1.setRemark("remark");
        adminRole1.setStatus(0);
        adminRole1.setCreateUser(0);
        adminRole1.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminRole1.setUpdateUser(0);
        adminRole1.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        final AdminPermission adminPermission1 = new AdminPermission();
        adminPermission1.setId(0);
        adminPermission1.setSign("sign");
        adminPermission1.setName("name");
        adminPermission1.setRemark("remark");
        adminPermission1.setStatus(0);
        adminPermission1.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminPermission1.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminRole1.setPermissions(new ArrayList<>(Collections.singletonList(adminPermission1)));
        final Optional<AdminRole> adminRole = Optional.of(adminRole1);
        when(mockAdminRoleRepository.findById(0)).thenReturn(adminRole);

        // Configure AdminPermissionRepository.findOne(...).
        final AdminPermission adminPermission3 = new AdminPermission();
        adminPermission3.setId(0);
        adminPermission3.setSign("sign");
        adminPermission3.setName("name");
        adminPermission3.setRemark("remark");
        adminPermission3.setStatus(0);
        adminPermission3.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminPermission3.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        final Optional<AdminPermission> adminPermission2 = Optional.of(adminPermission3);
        BooleanExpression booleanExpression = new QAdminPermission("adminPermission").sign.eq("sign");
        when(mockPermissionRepository.findOne(booleanExpression)).thenReturn(adminPermission2);

        // Configure AdminPermissionRepository.save(...).
        final AdminPermission adminPermission4 = new AdminPermission();
        adminPermission4.setId(0);
        adminPermission4.setSign("sign");
        adminPermission4.setName("name");
        adminPermission4.setRemark("remark");
        adminPermission4.setStatus(0);
        adminPermission4.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminPermission4.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        when(mockPermissionRepository.save(any(AdminPermission.class))).thenReturn(adminPermission4);

        // Configure AdminRoleRepository.save(...).
        final AdminRole adminRole2 = new AdminRole();
        adminRole2.setId(0);
        adminRole2.setName("name");
        adminRole2.setRemark("remark");
        adminRole2.setStatus(0);
        adminRole2.setCreateUser(0);
        adminRole2.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminRole2.setUpdateUser(0);
        adminRole2.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        final AdminPermission adminPermission5 = new AdminPermission();
        adminPermission5.setId(0);
        adminPermission5.setSign("sign");
        adminPermission5.setName("name");
        adminPermission5.setRemark("remark");
        adminPermission5.setStatus(0);
        adminPermission5.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminPermission5.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminRole2.setPermissions(new ArrayList<>(Collections.singletonList(adminPermission5)));
        when(mockAdminRoleRepository.save(any(AdminRole.class))).thenReturn(adminRole2);

        // Run the test
        final MapResponse result = adminRoleServiceUnderTest.update(param);

        // Verify the results
    }

    @Test
    void testUpdate_AdminRoleRepositoryFindByIdReturnsAbsent() {
        // Setup
        final AdminRole param = new AdminRole();
        param.setId(0);
        param.setName("name");
        param.setRemark("remark");
        param.setStatus(0);
        param.setCreateUser(0);
        param.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        param.setUpdateUser(0);
        param.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        final AdminPermission adminPermission = new AdminPermission();
        adminPermission.setId(0);
        adminPermission.setSign("sign");
        adminPermission.setName("name");
        adminPermission.setRemark("remark");
        adminPermission.setStatus(0);
        adminPermission.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminPermission.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        param.setPermissions(Arrays.asList(adminPermission));

        when(mockAdminRoleRepository.findById(0)).thenReturn(Optional.empty());

        // Configure AdminPermissionRepository.findOne(...).
        final AdminPermission adminPermission2 = new AdminPermission();
        adminPermission2.setId(0);
        adminPermission2.setSign("sign");
        adminPermission2.setName("name");
        adminPermission2.setRemark("remark");
        adminPermission2.setStatus(0);
        adminPermission2.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminPermission2.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        final Optional<AdminPermission> adminPermission1 = Optional.of(adminPermission2);
        when(mockPermissionRepository.findOne(new BooleanBuilder())).thenReturn(adminPermission1);

        // Configure AdminPermissionRepository.save(...).
        final AdminPermission adminPermission3 = new AdminPermission();
        adminPermission3.setId(0);
        adminPermission3.setSign("sign");
        adminPermission3.setName("name");
        adminPermission3.setRemark("remark");
        adminPermission3.setStatus(0);
        adminPermission3.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminPermission3.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        when(mockPermissionRepository.save(any(AdminPermission.class))).thenReturn(adminPermission3);

        // Configure AdminRoleRepository.save(...).
        final AdminRole adminRole = new AdminRole();
        adminRole.setId(0);
        adminRole.setName("name");
        adminRole.setRemark("remark");
        adminRole.setStatus(0);
        adminRole.setCreateUser(0);
        adminRole.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminRole.setUpdateUser(0);
        adminRole.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        final AdminPermission adminPermission4 = new AdminPermission();
        adminPermission4.setId(0);
        adminPermission4.setSign("sign");
        adminPermission4.setName("name");
        adminPermission4.setRemark("remark");
        adminPermission4.setStatus(0);
        adminPermission4.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminPermission4.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminRole.setPermissions(Arrays.asList(adminPermission4));
        when(mockAdminRoleRepository.save(any(AdminRole.class))).thenReturn(adminRole);

        // Run the test
        final MapResponse result = adminRoleServiceUnderTest.update(param);

        // Verify the results
    }

    @Test
    void testUpdate_AdminPermissionRepositoryFindOneReturnsAbsent() {
        // Setup
        final AdminRole param = new AdminRole();
        param.setId(0);
        param.setName("name");
        param.setRemark("remark");
        param.setStatus(0);
        param.setCreateUser(0);
        param.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        param.setUpdateUser(0);
        param.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        final AdminPermission adminPermission = new AdminPermission();
        adminPermission.setId(0);
        adminPermission.setSign("sign");
        adminPermission.setName("name");
        adminPermission.setRemark("remark");
        adminPermission.setStatus(0);
        adminPermission.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminPermission.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        param.setPermissions(Arrays.asList(adminPermission));

        // Configure AdminRoleRepository.findById(...).
        final AdminRole adminRole1 = new AdminRole();
        adminRole1.setId(0);
        adminRole1.setName("name");
        adminRole1.setRemark("remark");
        adminRole1.setStatus(0);
        adminRole1.setCreateUser(0);
        adminRole1.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminRole1.setUpdateUser(0);
        adminRole1.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        final AdminPermission adminPermission1 = new AdminPermission();
        adminPermission1.setId(0);
        adminPermission1.setSign("sign");
        adminPermission1.setName("name");
        adminPermission1.setRemark("remark");
        adminPermission1.setStatus(0);
        adminPermission1.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminPermission1.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminRole1.setPermissions(Arrays.asList(adminPermission1));
        final Optional<AdminRole> adminRole = Optional.of(adminRole1);
        when(mockAdminRoleRepository.findById(0)).thenReturn(adminRole);

        when(mockPermissionRepository.findOne(new BooleanBuilder())).thenReturn(Optional.empty());

        // Configure AdminPermissionRepository.save(...).
        final AdminPermission adminPermission2 = new AdminPermission();
        adminPermission2.setId(0);
        adminPermission2.setSign("sign");
        adminPermission2.setName("name");
        adminPermission2.setRemark("remark");
        adminPermission2.setStatus(0);
        adminPermission2.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminPermission2.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        when(mockPermissionRepository.save(any(AdminPermission.class))).thenReturn(adminPermission2);

        // Configure AdminRoleRepository.save(...).
        final AdminRole adminRole2 = new AdminRole();
        adminRole2.setId(0);
        adminRole2.setName("name");
        adminRole2.setRemark("remark");
        adminRole2.setStatus(0);
        adminRole2.setCreateUser(0);
        adminRole2.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminRole2.setUpdateUser(0);
        adminRole2.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        final AdminPermission adminPermission3 = new AdminPermission();
        adminPermission3.setId(0);
        adminPermission3.setSign("sign");
        adminPermission3.setName("name");
        adminPermission3.setRemark("remark");
        adminPermission3.setStatus(0);
        adminPermission3.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminPermission3.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminRole2.setPermissions(Arrays.asList(adminPermission3));
        when(mockAdminRoleRepository.save(any(AdminRole.class))).thenReturn(adminRole2);

        // Run the test
        final MapResponse result = adminRoleServiceUnderTest.update(param);

        // Verify the results
    }

    @Test
    void testDelete() {
        // Setup
        final AdminRole param = new AdminRole();
        param.setId(0);
        param.setName("name");
        param.setRemark("remark");
        param.setStatus(0);
        param.setCreateUser(0);
        param.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        param.setUpdateUser(0);
        param.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        final AdminPermission adminPermission = new AdminPermission();
        adminPermission.setId(0);
        adminPermission.setSign("sign");
        adminPermission.setName("name");
        adminPermission.setRemark("remark");
        adminPermission.setStatus(0);
        adminPermission.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminPermission.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        param.setPermissions(Arrays.asList(adminPermission));

        // Configure AdminRoleRepository.findById(...).
        final AdminRole adminRole1 = new AdminRole();
        adminRole1.setId(0);
        adminRole1.setName("name");
        adminRole1.setRemark("remark");
        adminRole1.setStatus(0);
        adminRole1.setCreateUser(0);
        adminRole1.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminRole1.setUpdateUser(0);
        adminRole1.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        final AdminPermission adminPermission1 = new AdminPermission();
        adminPermission1.setId(0);
        adminPermission1.setSign("sign");
        adminPermission1.setName("name");
        adminPermission1.setRemark("remark");
        adminPermission1.setStatus(0);
        adminPermission1.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminPermission1.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminRole1.setPermissions(Arrays.asList(adminPermission1));
        final Optional<AdminRole> adminRole = Optional.of(adminRole1);
        when(mockAdminRoleRepository.findById(0)).thenReturn(adminRole);

        // Configure AdminRoleRepository.save(...).
        final AdminRole adminRole2 = new AdminRole();
        adminRole2.setId(0);
        adminRole2.setName("name");
        adminRole2.setRemark("remark");
        adminRole2.setStatus(0);
        adminRole2.setCreateUser(0);
        adminRole2.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminRole2.setUpdateUser(0);
        adminRole2.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        final AdminPermission adminPermission2 = new AdminPermission();
        adminPermission2.setId(0);
        adminPermission2.setSign("sign");
        adminPermission2.setName("name");
        adminPermission2.setRemark("remark");
        adminPermission2.setStatus(0);
        adminPermission2.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminPermission2.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminRole2.setPermissions(Arrays.asList(adminPermission2));
        when(mockAdminRoleRepository.save(any(AdminRole.class))).thenReturn(adminRole2);

        // Run the test
        final MapResponse result = adminRoleServiceUnderTest.delete(param);

        // Verify the results
    }

    @Test
    void testDelete_AdminRoleRepositoryFindByIdReturnsAbsent() {
        // Setup
        final AdminRole param = new AdminRole();
        param.setId(0);
        param.setName("name");
        param.setRemark("remark");
        param.setStatus(0);
        param.setCreateUser(0);
        param.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        param.setUpdateUser(0);
        param.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        final AdminPermission adminPermission = new AdminPermission();
        adminPermission.setId(0);
        adminPermission.setSign("sign");
        adminPermission.setName("name");
        adminPermission.setRemark("remark");
        adminPermission.setStatus(0);
        adminPermission.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminPermission.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        param.setPermissions(Arrays.asList(adminPermission));

        when(mockAdminRoleRepository.findById(0)).thenReturn(Optional.empty());

        // Configure AdminRoleRepository.save(...).
        final AdminRole adminRole = new AdminRole();
        adminRole.setId(0);
        adminRole.setName("name");
        adminRole.setRemark("remark");
        adminRole.setStatus(0);
        adminRole.setCreateUser(0);
        adminRole.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminRole.setUpdateUser(0);
        adminRole.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        final AdminPermission adminPermission1 = new AdminPermission();
        adminPermission1.setId(0);
        adminPermission1.setSign("sign");
        adminPermission1.setName("name");
        adminPermission1.setRemark("remark");
        adminPermission1.setStatus(0);
        adminPermission1.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminPermission1.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminRole.setPermissions(Arrays.asList(adminPermission1));
        when(mockAdminRoleRepository.save(any(AdminRole.class))).thenReturn(adminRole);

        // Run the test
        final MapResponse result = adminRoleServiceUnderTest.delete(param);

        // Verify the results
    }
}
