package com.persagy.dmp.rwd.edit.service;

import com.fasterxml.jackson.databind.node.JsonNodeFactory;
import com.fasterxml.jackson.databind.node.ObjectNode;
import com.persagy.common.criteria.CriteriaExpressionParser;
import com.persagy.common.criteria.CriteriaUtils;
import com.persagy.common.criteria.JacksonCriteria;
import com.persagy.common.web.MapResponse;
import com.persagy.common.web.PagedResponse;
import com.persagy.dmp.rwd.edit.entity.QRwdeditRefTypeInfos;
import com.persagy.dmp.rwd.edit.entity.RwdeditRefTypeInfos;
import com.persagy.dmp.rwd.edit.repository.RwdeditRefTypeInfosRepository;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.junit.jupiter.MockitoExtension;

import java.util.Calendar;
import java.util.GregorianCalendar;

import static org.mockito.ArgumentMatchers.any;
import static org.mockito.ArgumentMatchers.eq;
import static org.mockito.Mockito.verify;
import static org.mockito.Mockito.when;

@ExtendWith(MockitoExtension.class)
class RwdeditRefTypeInfosServiceTest {

    @Mock
    private CriteriaUtils mockCriteriaUtils;
    @Mock
    private RwdeditRefTypeInfosRepository mockRepository;

    @InjectMocks
    private RwdeditRefTypeInfosService rwdeditRefTypeInfosServiceUnderTest;

    @Test
    void testQuery() {
        // Setup
        final JacksonCriteria criteria = JacksonCriteria.newInstance();
        when(mockCriteriaUtils.query(eq(new QRwdeditRefTypeInfos("variable")), any(CriteriaExpressionParser.class), any(JacksonCriteria.class))).thenReturn(new PagedResponse<>());

        // Run the test
        final PagedResponse<RwdeditRefTypeInfos> result = rwdeditRefTypeInfosServiceUnderTest.query(criteria);

        // Verify the results
    }

    @Test
    void testCreate() {
        // Setup
        final RwdeditRefTypeInfos refTypeInfos = new RwdeditRefTypeInfos();
        refTypeInfos.setRefKey("refKey");
        refTypeInfos.setCode("code");
        refTypeInfos.setName("name");
        refTypeInfos.setParentCode("parentCode");
        refTypeInfos.setDataSource(new ObjectNode(new JsonNodeFactory(false)));
        refTypeInfos.setCreateUser(0);
        refTypeInfos.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        refTypeInfos.setUpdateUser(0);
        refTypeInfos.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());

        when(mockCriteriaUtils.query(eq(new QRwdeditRefTypeInfos("variable")), any(CriteriaExpressionParser.class), any(JacksonCriteria.class))).thenReturn(new PagedResponse<>());

        // Configure RwdeditRefTypeInfosRepository.save(...).
        final RwdeditRefTypeInfos rwdeditRefTypeInfos = new RwdeditRefTypeInfos();
        rwdeditRefTypeInfos.setRefKey("refKey");
        rwdeditRefTypeInfos.setCode("code");
        rwdeditRefTypeInfos.setName("name");
        rwdeditRefTypeInfos.setParentCode("parentCode");
        rwdeditRefTypeInfos.setDataSource(new ObjectNode(new JsonNodeFactory(false)));
        rwdeditRefTypeInfos.setCreateUser(0);
        rwdeditRefTypeInfos.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        rwdeditRefTypeInfos.setUpdateUser(0);
        rwdeditRefTypeInfos.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        when(mockRepository.save(any(RwdeditRefTypeInfos.class))).thenReturn(rwdeditRefTypeInfos);

        // Run the test
        final MapResponse result = rwdeditRefTypeInfosServiceUnderTest.create(refTypeInfos);

        // Verify the results
    }

    @Test
    void testUpdate() {
        // Setup
        final RwdeditRefTypeInfos refTypeInfos = new RwdeditRefTypeInfos();
        refTypeInfos.setRefKey("refKey");
        refTypeInfos.setCode("code");
        refTypeInfos.setName("name");
        refTypeInfos.setParentCode("parentCode");
        refTypeInfos.setDataSource(new ObjectNode(new JsonNodeFactory(false)));
        refTypeInfos.setCreateUser(0);
        refTypeInfos.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        refTypeInfos.setUpdateUser(0);
        refTypeInfos.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());

        when(mockCriteriaUtils.query(eq(new QRwdeditRefTypeInfos("variable")), any(CriteriaExpressionParser.class), any(JacksonCriteria.class))).thenReturn(new PagedResponse<>());

        // Configure RwdeditRefTypeInfosRepository.save(...).
        final RwdeditRefTypeInfos rwdeditRefTypeInfos = new RwdeditRefTypeInfos();
        rwdeditRefTypeInfos.setRefKey("refKey");
        rwdeditRefTypeInfos.setCode("code");
        rwdeditRefTypeInfos.setName("name");
        rwdeditRefTypeInfos.setParentCode("parentCode");
        rwdeditRefTypeInfos.setDataSource(new ObjectNode(new JsonNodeFactory(false)));
        rwdeditRefTypeInfos.setCreateUser(0);
        rwdeditRefTypeInfos.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        rwdeditRefTypeInfos.setUpdateUser(0);
        rwdeditRefTypeInfos.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        when(mockRepository.save(any(RwdeditRefTypeInfos.class))).thenReturn(rwdeditRefTypeInfos);

        // Run the test
        final MapResponse result = rwdeditRefTypeInfosServiceUnderTest.update(refTypeInfos);

        // Verify the results
    }

    @Test
    void testDelete() {
        // Setup
        final RwdeditRefTypeInfos refTypeInfos = new RwdeditRefTypeInfos();
        refTypeInfos.setRefKey("refKey");
        refTypeInfos.setCode("code");
        refTypeInfos.setName("name");
        refTypeInfos.setParentCode("parentCode");
        refTypeInfos.setDataSource(new ObjectNode(new JsonNodeFactory(false)));
        refTypeInfos.setCreateUser(0);
        refTypeInfos.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        refTypeInfos.setUpdateUser(0);
        refTypeInfos.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());

        when(mockCriteriaUtils.query(eq(new QRwdeditRefTypeInfos("variable")), any(CriteriaExpressionParser.class), any(JacksonCriteria.class))).thenReturn(new PagedResponse<>());

        // Run the test
        final MapResponse result = rwdeditRefTypeInfosServiceUnderTest.delete(refTypeInfos);

        // Verify the results
        verify(mockRepository).delete(any(RwdeditRefTypeInfos.class));
    }
}
